from setuptools import setup

setup (name="saylaniCalc",
version="0.1",
description="this is a package",
long_description="this is a very very long description",
author = "Sir Qasim and Syed Muhammad Mooazam",
packages = ["saylaniCalc"],
install_packages = []
)